==> python-exchangelib_4.7.6.orig.tar.gz: exchangelib-4.7.6/exchangelib/folders/__init__.py <==
from ..properties import DistinguishedFolderId, FolderId
from .base import BaseFolder, Folder
from .collections import FolderCollection
from .known_folders import (
    NON_DELETABLE_FOLDERS,
    AdminAuditLogs,
    AllContacts,
    AllItems,
    ApplicationData,
    ArchiveDeletedItems,
    ArchiveInbox,
    ArchiveMsgFolderRoot,
    ArchiveRecoverableItemsDeletions,
    ArchiveRecoverableItemsPurges,
    ArchiveRecoverableItemsRoot,
    ArchiveRecoverableItemsVersions,
    Audits,
    Birthdays,
    Calendar,
    CalendarLogging,
    CommonViews,
    Companies,
    Conflicts,
    Contacts,
    ConversationHistory,
    ConversationSettings,
    CrawlerData,
    DefaultFoldersChangeHistory,
    DeferredAction,
    DeletedItems,
    Directory,
    DlpPolicyEvaluation,
    Drafts,
    ExchangeSyncData,
    Favorites,
    Files,
    FreeBusyCache,
    FreebusyData,
    Friends,
    GALContacts,
    GraphAnalytics,
    IMContactList,
    Inbox,
    Journal,
    JunkEmail,
    LocalFailures,
    Location,
    MailboxAssociations,
    Messages,
    MsgFolderRoot,
    MyContacts,
    MyContactsExtended,
    NonDeletableFolderMixin,
    Notes,
    OrganizationalContacts,
    Outbox,
    ParkedMessages,
    PassThroughSearchResults,
    PdpProfileV2Secured,
    PeopleCentricConversationBuddies,
    PeopleConnect,
    QuickContacts,
    RecipientCache,
    RecoverableItemsDeletions,
    RecoverableItemsPurges,
    RecoverableItemsRoot,
    RecoverableItemsVersions,
    RecoveryPoints,
    Reminders,
    RSSFeeds,
    Schedule,
    SearchFolders,
    SentItems,
    ServerFailures,
    Sharing,
    Shortcuts,
    Signal,
    SkypeTeamsMessages,
    SmsAndChatsSync,
    SpoolerQueue,
    SwssItems,
    SyncIssues,
    System,
    Tasks,
    TemporarySaves,
    ToDoSearch,
    Views,
    VoiceMail,
    WellknownFolder,
    WorkingSet,
)
from .queryset import DEEP, FOLDER_TRAVERSAL_CHOICES, SHALLOW, SOFT_DELETED, FolderQuerySet, SingleFolderQuerySet
from .roots import ArchiveRoot, PublicFoldersRoot, Root, RootOfHierarchy

__all__ = [
    "AdminAuditLogs",
    "AllContacts",
    "AllItems",
    "ApplicationData",
    "ArchiveDeletedItems",
    "ArchiveInbox",
    "ArchiveMsgFolderRoot",
    "ArchiveRecoverableItemsDeletions",
    "ArchiveRecoverableItemsPurges",
    "ArchiveRecoverableItemsRoot",
    "ArchiveRecoverableItemsVersions",
    "ArchiveRoot",
    "Audits",
    "BaseFolder",
    "Birthdays",
    "Calendar",
    "CalendarLogging",
    "CommonViews",
    "Companies",
    "Conflicts",
    "Contacts",
    "ConversationHistory",
    "ConversationSettings",
    "CrawlerData",
    "DEEP",
    "DefaultFoldersChangeHistory",
    "DeferredAction",
    "DeletedItems",
    "Directory",
    "DistinguishedFolderId",
    "DlpPolicyEvaluation",
    "Drafts",
    "ExchangeSyncData",
    "FOLDER_TRAVERSAL_CHOICES",
    "Favorites",
    "Files",
    "Folder",
    "FolderCollection",
    "FolderId",
    "FolderQuerySet",
    "FreeBusyCache",
    "FreebusyData",
    "Friends",
    "GALContacts",
    "GraphAnalytics",
    "IMContactList",
    "Inbox",
    "Journal",
    "JunkEmail",
    "LocalFailures",
    "Location",
    "MailboxAssociations",
    "Messages",
    "MsgFolderRoot",
    "MyContacts",
    "MyContactsExtended",
    "NON_DELETABLE_FOLDERS",
    "NonDeletableFolderMixin",
    "Notes",
    "OrganizationalContacts",
    "Outbox",
    "ParkedMessages",
    "PassThroughSearchResults",
    "PdpProfileV2Secured",
    "PeopleCentricConversationBuddies",
    "PeopleConnect",
    "PublicFoldersRoot",
    "QuickContacts",
    "RSSFeeds",
    "RecipientCache",
    "RecoverableItemsDeletions",
    "RecoverableItemsPurges",
    "RecoverableItemsRoot",
    "RecoverableItemsVersions",
    "RecoveryPoints",
    "Reminders",
    "Root",
    "RootOfHierarchy",
    "SHALLOW",
    "SOFT_DELETED",
    "Schedule",
    "SearchFolders",
    "SentItems",
    "ServerFailures",
    "Sharing",
    "Shortcuts",
    "Signal",
    "SingleFolderQuerySet",
    "SkypeTeamsMessages",
    "SmsAndChatsSync",
    "SpoolerQueue",
    "SwssItems",
    "SyncIssues",
    "System",
    "Tasks",
    "TemporarySaves",
    "ToDoSearch",
    "Views",
    "VoiceMail",
    "WellknownFolder",
    "WorkingSet",
]

==> python-exchangelib_4.9.0.orig.tar.gz: exchangelib-4.9.0/exchangelib/folders/__init__.py <==
from ..properties import DistinguishedFolderId, FolderId
from .base import BaseFolder, Folder
from .collections import FolderCollection
from .known_folders import (
    NON_DELETABLE_FOLDERS,
    AdminAuditLogs,
    AllContacts,
    AllItems,
    ApplicationData,
    ArchiveDeletedItems,
    ArchiveInbox,
    ArchiveMsgFolderRoot,
    ArchiveRecoverableItemsDeletions,
    ArchiveRecoverableItemsPurges,
    ArchiveRecoverableItemsRoot,
    ArchiveRecoverableItemsVersions,
    Audits,
    Birthdays,
    Calendar,
    CalendarLogging,
    CommonViews,
    Companies,
    Conflicts,
    Contacts,
    ConversationHistory,
    ConversationSettings,
    CrawlerData,
    DefaultFoldersChangeHistory,
    DeferredAction,
    DeletedItems,
    Directory,
    DlpPolicyEvaluation,
    Drafts,
    ExchangeSyncData,
    Favorites,
    Files,
    FreeBusyCache,
    FreebusyData,
    Friends,
    GALContacts,
    GraphAnalytics,
    IMContactList,
    Inbox,
    Journal,
    JunkEmail,
    LocalFailures,
    Location,
    MailboxAssociations,
    Messages,
    MsgFolderRoot,
    MyContacts,
    MyContactsExtended,
    NonDeletableFolderMixIn,
    Notes,
    OrganizationalContacts,
    Outbox,
    ParkedMessages,
    PassThroughSearchResults,
    PdpProfileV2Secured,
    PeopleCentricConversationBuddies,
    PeopleConnect,
    QuickContacts,
    RecipientCache,
    RecoverableItemsDeletions,
    RecoverableItemsPurges,
    RecoverableItemsRoot,
    RecoverableItemsVersions,
    RecoveryPoints,
    Reminders,
    RSSFeeds,
    Schedule,
    SearchFolders,
    SentItems,
    ServerFailures,
    Sharing,
    Shortcuts,
    Signal,
    SkypeTeamsMessages,
    SmsAndChatsSync,
    SpoolerQueue,
    SwssItems,
    SyncIssues,
    System,
    Tasks,
    TemporarySaves,
    ToDoSearch,
    Views,
    VoiceMail,
    WellknownFolder,
    WorkingSet,
)
from .queryset import DEEP, FOLDER_TRAVERSAL_CHOICES, SHALLOW, SOFT_DELETED, FolderQuerySet, SingleFolderQuerySet
from .roots import ArchiveRoot, PublicFoldersRoot, Root, RootOfHierarchy

__all__ = [
    "AdminAuditLogs",
    "AllContacts",
    "AllItems",
    "ApplicationData",
    "ArchiveDeletedItems",
    "ArchiveInbox",
    "ArchiveMsgFolderRoot",
    "ArchiveRecoverableItemsDeletions",
    "ArchiveRecoverableItemsPurges",
    "ArchiveRecoverableItemsRoot",
    "ArchiveRecoverableItemsVersions",
    "ArchiveRoot",
    "Audits",
    "BaseFolder",
    "Birthdays",
    "Calendar",
    "CalendarLogging",
    "CommonViews",
    "Companies",
    "Conflicts",
    "Contacts",
    "ConversationHistory",
    "ConversationSettings",
    "CrawlerData",
    "DEEP",
    "DefaultFoldersChangeHistory",
    "DeferredAction",
    "DeletedItems",
    "Directory",
    "DistinguishedFolderId",
    "DlpPolicyEvaluation",
    "Drafts",
    "ExchangeSyncData",
    "FOLDER_TRAVERSAL_CHOICES",
    "Favorites",
    "Files",
    "Folder",
    "FolderCollection",
    "FolderId",
    "FolderQuerySet",
    "FreeBusyCache",
    "FreebusyData",
    "Friends",
    "GALContacts",
    "GraphAnalytics",
    "IMContactList",
    "Inbox",
    "Journal",
    "JunkEmail",
    "LocalFailures",
    "Location",
    "MailboxAssociations",
    "Messages",
    "MsgFolderRoot",
    "MyContacts",
    "MyContactsExtended",
    "NON_DELETABLE_FOLDERS",
    "NonDeletableFolderMixIn",
    "Notes",
    "OrganizationalContacts",
    "Outbox",
    "ParkedMessages",
    "PassThroughSearchResults",
    "PdpProfileV2Secured",
    "PeopleCentricConversationBuddies",
    "PeopleConnect",
    "PublicFoldersRoot",
    "QuickContacts",
    "RSSFeeds",
    "RecipientCache",
    "RecoverableItemsDeletions",
    "RecoverableItemsPurges",
    "RecoverableItemsRoot",
    "RecoverableItemsVersions",
    "RecoveryPoints",
    "Reminders",
    "Root",
    "RootOfHierarchy",
    "SHALLOW",
    "SOFT_DELETED",
    "Schedule",
    "SearchFolders",
    "SentItems",
    "ServerFailures",
    "Sharing",
    "Shortcuts",
    "Signal",
    "SingleFolderQuerySet",
    "SkypeTeamsMessages",
    "SmsAndChatsSync",
    "SpoolerQueue",
    "SwssItems",
    "SyncIssues",
    "System",
    "Tasks",
    "TemporarySaves",
    "ToDoSearch",
    "Views",
    "VoiceMail",
    "WellknownFolder",
    "WorkingSet",
]
